@@ -1,6 +1,7 @@
 import json
 import logging
 
+import pytz
 from django.conf import settings
 from django.db.models.fields import timezone
 from django.http import HttpResponseRedirect
@@ -10,7 +11,8 @@ from django.views.decorators.csrf import csrf_exempt
 from django.views.generic import FormView
 from django.views.generic.list import ListView
 from rest_framework import status
-from rest_framework.decorators import api_view
+from rest_framework.decorators import api_view, permission_classes
+from rest_framework.permissions import IsAuthenticated
 from rest_framework.response import Response
 from scrobbles.constants import (
     JELLYFIN_AUDIO_ITEM_TYPES,
@@ -45,31 +47,45 @@ class RecentScrobbleList(ListView):
 
     def get_context_data(self, **kwargs):
         data = super().get_context_data(**kwargs)
+        user = self.request.user
         now = timezone.now()
-        data['now_playing_list'] = Scrobble.objects.filter(
-            in_progress=True,
-            is_paused=False,
-            timestamp__lte=now,
-        )
-        data['video_scrobble_list'] = Scrobble.objects.filter(
-            video__isnull=False, played_to_completion=True
-        ).order_by('-timestamp')[:15]
-        data['podcast_scrobble_list'] = Scrobble.objects.filter(
-            podcast_episode__isnull=False, played_to_completion=True
-        ).order_by('-timestamp')[:15]
-        data['sport_scrobble_list'] = Scrobble.objects.filter(
-            sport_event__isnull=False, played_to_completion=True
-        ).order_by('-timestamp')[:15]
-        data['top_daily_tracks'] = top_tracks()
-        data['top_weekly_tracks'] = top_tracks(filter='week')
-        data['top_monthly_tracks'] = top_tracks(filter='month')
+        if user.is_authenticated:
+            if user.profile:
+                timezone.activate(pytz.timezone(user.profile.timezone))
+                now = timezone.localtime(timezone.now())
+            data['now_playing_list'] = Scrobble.objects.filter(
+                in_progress=True,
+                is_paused=False,
+                timestamp__lte=now,
+                user=user,
+            )
 
-        data['top_daily_artists'] = top_artists()
-        data['top_weekly_artists'] = top_artists(filter='week')
-        data['top_monthly_artists'] = top_artists(filter='month')
+            completed_for_user = Scrobble.objects.filter(
+                played_to_completion=True, user=user
+            )
+            data['video_scrobble_list'] = completed_for_user.filter(
+                video__isnull=False
+            ).order_by('-timestamp')[:15]
 
-        data["weekly_data"] = week_of_scrobbles()
-        data['counts'] = scrobble_counts()
+            data['podcast_scrobble_list'] = completed_for_user.filter(
+                podcast_episode__isnull=False
+            ).order_by('-timestamp')[:15]
+
+            data['sport_scrobble_list'] = completed_for_user.filter(
+                sport_event__isnull=False
+            ).order_by('-timestamp')[:15]
+
+            # data['top_daily_tracks'] = top_tracks()
+            data['top_weekly_tracks'] = top_tracks(user, filter='week')
+            data['top_monthly_tracks'] = top_tracks(user, filter='month')
+
+            # data['top_daily_artists'] = top_artists()
+            data['top_weekly_artists'] = top_artists(user, filter='week')
+            data['top_monthly_artists'] = top_artists(user, filter='month')
+
+        data["weekly_data"] = week_of_scrobbles(user=user)
+
+        data['counts'] = scrobble_counts(user)
         data['imdb_form'] = ScrobbleForm
         return data
 
@@ -116,6 +132,7 @@ def scrobble_endpoint(request):
 
 @csrf_exempt
 @api_view(['POST'])
+@permission_classes([IsAuthenticated])
 def jellyfin_websocket(request):
     data_dict = request.data
 
@@ -141,8 +158,13 @@ def jellyfin_websocket(request):
 
 @csrf_exempt
 @api_view(['POST'])
+@permission_classes([IsAuthenticated])
 def mopidy_websocket(request):
-    data_dict = json.loads(request.data)
+    try:
+        data_dict = json.loads(request.data)
+    except TypeError:
+        logger.warning('Received Mopidy data as dict, rather than a string')
+        data_dict = request.data
 
     # For making things easier to build new input processors
     if getattr(settings, "DUMP_REQUEST_DATA", False):
@@ -158,3 +180,38 @@ def mopidy_websocket(request):
         return Response({}, status=status.HTTP_400_BAD_REQUEST)
 
     return Response({'scrobble_id': scrobble.id}, status=status.HTTP_200_OK)
+
+
+@csrf_exempt
+@api_view(['GET'])
+@permission_classes([IsAuthenticated])
+def scrobble_finish(request, uuid):
+    user = request.user
+    if not user.is_authenticated:
+        return Response({}, status=status.HTTP_403_FORBIDDEN)
+
+    scrobble = Scrobble.objects.filter(user=user, uuid=uuid).first()
+    if not scrobble:
+        return Response({}, status=status.HTTP_404_NOT_FOUND)
+    scrobble.stop(force_finish=True)
+    return Response(
+        {'id': scrobble.id, 'status': scrobble.status},
+        status=status.HTTP_200_OK,
+    )
+
+
+@csrf_exempt
+@api_view(['GET'])
+@permission_classes([IsAuthenticated])
+def scrobble_cancel(request, uuid):
+    user = request.user
+    if not user.is_authenticated:
+        return Response({}, status=status.HTTP_403_FORBIDDEN)
+
+    scrobble = Scrobble.objects.filter(user=user, uuid=uuid).first()
+    if not scrobble:
+        return Response({}, status=status.HTTP_404_NOT_FOUND)
+    scrobble.cancel()
+    return Response(
+        {'id': scrobble.id, 'status': 'cancelled'}, status=status.HTTP_200_OK
+    )
